Index: src/ia32/builtins-ia32.cc |
=================================================================== |
--- src/ia32/builtins-ia32.cc (revision 2967) |
+++ src/ia32/builtins-ia32.cc (working copy) |
@@ -42,10 +42,10 @@ |
__ mov(Operand::StaticVariable(passed), edi); |
// The actual argument count has already been loaded into register |
// eax, but JumpToBuiltin expects eax to contain the number of |
// arguments including the receiver. |
__ inc(eax); |
- __ JumpToBuiltin(ExternalReference(id)); |
+ __ JumpToRuntime(ExternalReference(id)); |
} |
@@ -42,10 +42,10 @@ |
__ mov(Operand::StaticVariable(passed), edi); |
// The actual argument count has already been loaded into register |
- // eax, but JumpToBuiltin expects eax to contain the number of |
+ // eax, but JumpToRuntime expects eax to contain the number of |
// arguments including the receiver. |
__ inc(eax); |